gchecky.data

Package gchecky :: Module data |
[hide private]
[frames] | no frames]

# Module data

source code

Classes | [hide private]
| CountryCode
| PresentOrNot

Variables | [hide private]
| COUNTRY_CODES = ``{``'``AD``'``:` `'``ANDORRA``'``,` `'``AE``'``:` `'``UNITED ARAB EMIRATES``'``...``

Variables Details | [hide private]

  ### COUNTRY_CODES Value:
      {'AD': 'ANDORRA',
       'AE': 'UNITED ARAB EMIRATES',
       'AF': 'AFGHANISTAN',
       'AG': 'ANTIGUA AND BARBUDA',
       'AI': 'ANGUILLA',
       'AL': 'ALBANIA',
       'AM': 'ARMENIA',
       'AN': 'NETHERLANDS ANTILLES',
      ...